Learn R Programming

RPS (version 1.0.0)

readland.txtJ: Reads a MorphoJ txt file and returns it as a s-dimensional array of n * k matrix

Description

Reads a MorphoJ txt file and returns it as a s-dimensional array of n * k matrix

Usage

readland.txtJ(path, dim)

Arguments

path

Path of file.

dim

Dimension of the configuration (2D OR 3D).

Value

A s-dimensional array of n * k matrix and a list of specimens names.